ConcurrencyClass

Enum ConcurrencyClass 

pub enum ConcurrencyClass {
    Stateless,
    OrderedStateful,
    Source,
}
Declares how scheduler may run node callbacks across frames.

Variants



Stateless

Callback has no cross-frame mutable state.



OrderedStateful

Callback may prepare out of order but must commit in increasing frame order.



Callback is a source and may declare source-specific capability limits.

Implementations

Source

impl ConcurrencyClass

pub const fn as_str(self) -> &'static str

Returns stable diagnostic name.