DynamicDependencyBounds

Enum DynamicDependencyBounds 

pub enum DynamicDependencyBounds {
    Any,
    PastOnly,
    FutureWindow {
        after: usize,
    },
    Bounded {
        before: usize,
        after: usize,
    },
}
Runtime bounds for frame-map and dynamic dependencies.

Variants



Any

Any frame in finite clip range may be requested.



PastOnly

Requested frame must be less than or equal to output frame.



FutureWindow

Requested frame must be in [output, output + after].

Fields

after: usize

Maximum number of frames allowed after output frame.



Bounded

Requested frame must be in [output - before, output + after].

Fields

before: usize

Maximum number of frames allowed before output frame.

after: usize

Maximum number of frames allowed after output frame.

Implementations

Source

impl DynamicDependencyBounds

pub const fn any() -> Self

Creates unbounded dynamic access.

pub const fn past_only() -> Self

Creates past-only dynamic access.

pub const fn future_window(after: usize) -> Self

Creates future-window dynamic access.

pub const fn bounded(before: usize, after: usize) -> Self

Creates bounded dynamic access.

pub const fn allows(self, output: usize, requested: usize) -> bool

Returns true when requested frame is allowed for one output frame.