Core abstractions shared by PixelFlow crates.
Re-exports
pub use core::Core;pub use core::CoreConfig;pub use error::ErrorCategory;pub use error::ErrorCode;pub use error::PixelFlowError;pub use error::Result;pub use filter::FilterDescriptor;pub use filter::FilterOptionValue;pub use filter::FilterOptions;pub use filter::FilterPlan;pub use filter::FilterPlanRequest;pub use filter::FilterPlanner;pub use filter::FilterRegistry;pub use format::ChromaSiting;pub use format::ChromaSubsampling;pub use format::ColorMatrix;pub use format::ColorPrimaries;pub use format::ColorRange;pub use format::ColorTransfer;pub use format::FormatDescriptor;pub use format::FormatFamily;pub use format::PlaneDescriptor;pub use format::PlaneRole;pub use format::SampleType;pub use format::format_with_bit_depth;pub use format::resolve_format_alias;pub use frame::AllocatorConfig;pub use frame::Frame;pub use frame::FrameBuilder;pub use frame::Plane;pub use frame::PlaneMut;pub use frame::PlaneRows;pub use frame::RawPlane;pub use frame::RawPlaneMut;pub use frame::Sample;pub use graph::Clip;pub use graph::ClipFormat;pub use graph::ClipMedia;pub use graph::ClipResolution;pub use graph::FilterChangeSet;pub use graph::FilterCompatibility;pub use graph::FrameCount;pub use graph::FrameRate;pub use graph::Graph;pub use graph::GraphBuilder;pub use graph::GraphNode;pub use graph::NodeId;pub use graph::NodeKind;pub use graph::ValidatedGraph;pub use graph::ValidationPlan;pub use graph::is_y4m_compatible_format;pub use log::LogLevel;pub use log::LogRecord;pub use log::LogSink;pub use log::Logger;pub use log::NoopLogSink;pub use metadata::Metadata;pub use metadata::MetadataKind;pub use metadata::MetadataSchema;pub use metadata::MetadataValue;pub use metadata::Rational;pub use plugin_abi::PIXELFLOW_ABI_VERSION;pub use plugin_abi::PIXELFLOW_PLUGIN_ENTRY_SYMBOL;pub use plugin_abi::PixelflowErrorCategory;pub use plugin_abi::PixelflowFilterDescriptorV1;pub use plugin_abi::PixelflowHostApiV1;pub use plugin_abi::PixelflowMetadataKind;pub use plugin_abi::PixelflowPluginApiV1;pub use plugin_abi::PixelflowPluginEntryV1;pub use plugin_abi::PixelflowRegistrar;pub use plugin_abi::PixelflowStatus;pub use plugin_abi::PixelflowStringView;pub use plugin_host::LoadedPlugin;pub use plugin_host::is_dynamic_library;pub use plugin_host::load_plugins_from_directories;pub use plugin_host::platform_plugin_directories;pub use render::FrameExecutor;pub use render::FrameRequest;pub use render::OrderedRender;pub use render::RenderEngine;pub use render::RenderExecutorMap;pub use render::RenderOptions;pub use render::RenderRange;pub use scheduler::ConcurrencyClass;pub use scheduler::DependencyPattern;pub use scheduler::DynamicDependencyBounds;pub use scheduler::FilterTiming;pub use scheduler::SourceCapabilities;pub use scheduler::TimingReport;pub use scheduler::WorkerPoolConfig;pub use source::SourceOptionValue;pub use source::SourceRequest;pub use y4m::Y4mWriter;pub use y4m::y4m_chroma_tag;
Modules
- core
- Core runtime owner for per-instance registries and plugin loading.
- error
- Structured error types for PixelFlow core and downstream crates.
- filter
- Filter and plugin capability registry types.
- format
- Pixel format descriptors and alias resolution.
- frame
- Immutable frames, aligned plane storage, and typed plane views.
- graph
- Immutable graph construction and Phase 1 validation.
- log
- Logging hook abstractions for libraries, CLI, and plugins.
- metadata
- Typed frame metadata values and schema enforcement.
- plugin_
abi - Versioned C-compatible ABI types shared by host and plugins.
- plugin_
host - Dynamic plugin loading and ABI host callback bridge.
- render
- Demand-driven blocking ordered render API.
- scheduler
- Scheduling contracts and per-core worker configuration.
- source
- Source request metadata shared by graph construction and source plugins.
- y4m
- Y4M stream writer for Phase 1 compatible formats.
Functions
- version
- Returns the
pixelflow-corecrate version.